
Integration plans for friends
=============================

This directory contains plans to be used for integration testing
with projects closely related to `tmt`. They can simply reference
the remote plan in their CI configuration to keep things stable.
